@@ -45,7 +45,7 @@ pub struct Settings {
     pub ranking_rules: Option<Vec<String>>,
     /// Attributes to use as [facets](https://docs.meilisearch.com/reference/features/faceted_search.html)
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub attributes_for_faceting: Option<Vec<String>>,
+    pub filterable_attributes: Option<Vec<String>>,
     /// Search returns documents with distinct (different) values of the given field
     #[serde(skip_serializing_if = "Option::is_none")]
     pub distinct_attribute: Option<String>,
@@ -160,7 +160,7 @@ impl Settings {
             synonyms: None,
             stop_words: None,
             ranking_rules: None,
-            attributes_for_faceting: None,
+            filterable_attributes: None,
             distinct_attribute: None,
             searchable_attributes: None,
             displayed_attributes: None,
@@ -192,9 +192,9 @@ impl Settings {
             ..self
         }
     }
-    pub fn with_attributes_for_faceting<T: IntoVecString>(self, attributes_for_faceting: T) -> Settings {
+    pub fn with_filterable_attributes<T: IntoVecString>(self, filterable_attributes: T) -> Settings {
         Settings {
-            attributes_for_faceting: Some(attributes_for_faceting.convert()),
+            filterable_attributes: Some(filterable_attributes.convert()),
             ..self
         }
     }
@@ -302,12 +302,12 @@ impl Index {
     /// # futures::executor::block_on(async move {
     /// let client = Client::new("http://localhost:7700", "masterKey");
     /// let movie_index = client.get_or_create("movies").await.unwrap();
-    /// let attributes_for_faceting = movie_index.get_attributes_for_faceting().await.unwrap();
+    /// let filterable_attributes = movie_index.get_filterable_attributes().await.unwrap();
     /// # });
     /// ```
-    pub async fn get_attributes_for_faceting(&self) -> Result<Vec<String>, Error> {
+    pub async fn get_filterable_attributes(&self) -> Result<Vec<String>, Error> {
         Ok(request::<(), Vec<String>>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &format!("{}/indexes/{}/settings/filterable-attributes", self.host, self.uid),
             &self.api_key,
             Method::Get,
             200,
@@ -468,11 +468,10 @@ impl Index {
     /// let mut movie_index = client.get_or_create("movies").await.unwrap();
     ///
     /// let ranking_rules = [
-    ///     "typo",
     ///     "words",
+    ///     "typo",
     ///     "proximity",
     ///     "attribute",
-    ///     "wordsPosition",
     ///     "exactness",
     ///     "asc(release_date)",
     ///     "desc(rank)",
@@ -502,17 +501,17 @@ impl Index {
     /// let client = Client::new("http://localhost:7700", "masterKey");
     /// let mut movie_index = client.get_or_create("movies").await.unwrap();
     ///
-    /// let attributes_for_faceting = ["genre", "director"];
-    /// let progress = movie_index.set_attributes_for_faceting(&attributes_for_faceting).await.unwrap();
+    /// let filterable_attributes = ["genre", "director"];
+    /// let progress = movie_index.set_filterable_attributes(&filterable_attributes).await.unwrap();
     /// # std::thread::sleep(std::time::Duration::from_secs(2));
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn set_attributes_for_faceting(&self, attributes_for_faceting: impl IntoVecString) -> Result<Progress, Error> {
+    pub async fn set_filterable_attributes(&self, filterable_attributes: impl IntoVecString) -> Result<Progress, Error> {
         Ok(request::<Vec<String>, ProgressJson>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &format!("{}/indexes/{}/settings/filterable-attributes", self.host, self.uid),
             &self.api_key,
-            Method::Post(attributes_for_faceting.convert()),
+            Method::Post(filterable_attributes.convert()),
             202,
         ).await?
         .into_progress(self))
@@ -670,7 +669,7 @@ impl Index {
     }
 
     /// Reset [ranking rules](https://docs.meilisearch.com/learn/core_concepts/relevancy.html#ranking-rules) of the index to default value.
-    /// Default value: ["typo", "words", "proximity", "attribute", "wordsPosition", "exactness"].
+    /// Default value: ["words", "typo", "proximity", "attribute", "exactness"].
     ///
     /// # Example
     ///
@@ -705,14 +704,14 @@ impl Index {
     /// let client = Client::new("http://localhost:7700", "masterKey");
     /// let mut movie_index = client.get_or_create("movies").await.unwrap();
     ///
-    /// let progress = movie_index.reset_attributes_for_faceting().await.unwrap();
+    /// let progress = movie_index.reset_filterable_attributes().await.unwrap();
     /// # std::thread::sleep(std::time::Duration::from_secs(2));
     /// # progress.get_status().await.unwrap();
     /// # });
     /// ```
-    pub async fn reset_attributes_for_faceting(&self) -> Result<Progress, Error> {
+    pub async fn reset_filterable_attributes(&self) -> Result<Progress, Error> {
         Ok(request::<(), ProgressJson>(
-            &format!("{}/indexes/{}/settings/attributes-for-faceting", self.host, self.uid),
+            &format!("{}/indexes/{}/settings/filterable-attributes", self.host, self.uid),
             &self.api_key,
             Method::Delete,
             202,
